
/* Generated data (by glib-mkenums) */

#include "gedit-enum-types.h"

/* enumerations from "gedit/gedit-notebook.h" */
#include "gedit/gedit-notebook.h"

GType
gedit_notebook_show_tabs_mode_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GEDIT_NOTEBOOK_SHOW_TABS_NEVER,
			  "GEDIT_NOTEBOOK_SHOW_TABS_NEVER",
			  "never" },
			{ GEDIT_NOTEBOOK_SHOW_TABS_AUTO,
			  "GEDIT_NOTEBOOK_SHOW_TABS_AUTO",
			  "auto" },
			{ GEDIT_NOTEBOOK_SHOW_TABS_ALWAYS,
			  "GEDIT_NOTEBOOK_SHOW_TABS_ALWAYS",
			  "always" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GeditNotebookShowTabsModeType"),
				values);
	}
	return the_type;
}

/* enumerations from "gedit/gedit-app.h" */
#include "gedit/gedit-app.h"

GType
gedit_lockdown_mask_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GEDIT_LOCKDOWN_COMMAND_LINE,
			  "GEDIT_LOCKDOWN_COMMAND_LINE",
			  "command-line" },
			{ GEDIT_LOCKDOWN_PRINTING,
			  "GEDIT_LOCKDOWN_PRINTING",
			  "printing" },
			{ GEDIT_LOCKDOWN_PRINT_SETUP,
			  "GEDIT_LOCKDOWN_PRINT_SETUP",
			  "print-setup" },
			{ GEDIT_LOCKDOWN_SAVE_TO_DISK,
			  "GEDIT_LOCKDOWN_SAVE_TO_DISK",
			  "save-to-disk" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GeditLockdownMask"),
				values);
	}
	return the_type;
}

/* enumerations from "gedit/gedit-debug.h" */
#include "gedit/gedit-debug.h"

GType
gedit_debug_section_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GEDIT_NO_DEBUG,
			  "GEDIT_NO_DEBUG",
			  "no-debug" },
			{ GEDIT_DEBUG_VIEW,
			  "GEDIT_DEBUG_VIEW",
			  "debug-view" },
			{ GEDIT_DEBUG_PREFS,
			  "GEDIT_DEBUG_PREFS",
			  "debug-prefs" },
			{ GEDIT_DEBUG_WINDOW,
			  "GEDIT_DEBUG_WINDOW",
			  "debug-window" },
			{ GEDIT_DEBUG_PANEL,
			  "GEDIT_DEBUG_PANEL",
			  "debug-panel" },
			{ GEDIT_DEBUG_PLUGINS,
			  "GEDIT_DEBUG_PLUGINS",
			  "debug-plugins" },
			{ GEDIT_DEBUG_TAB,
			  "GEDIT_DEBUG_TAB",
			  "debug-tab" },
			{ GEDIT_DEBUG_DOCUMENT,
			  "GEDIT_DEBUG_DOCUMENT",
			  "debug-document" },
			{ GEDIT_DEBUG_COMMANDS,
			  "GEDIT_DEBUG_COMMANDS",
			  "debug-commands" },
			{ GEDIT_DEBUG_APP,
			  "GEDIT_DEBUG_APP",
			  "debug-app" },
			{ GEDIT_DEBUG_UTILS,
			  "GEDIT_DEBUG_UTILS",
			  "debug-utils" },
			{ GEDIT_DEBUG_METADATA,
			  "GEDIT_DEBUG_METADATA",
			  "debug-metadata" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GeditDebugSection"),
				values);
	}
	return the_type;
}

/* enumerations from "gedit/gedit-tab.h" */
#include "gedit/gedit-tab.h"

GType
gedit_tab_state_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GEDIT_TAB_STATE_NORMAL,
			  "GEDIT_TAB_STATE_NORMAL",
			  "state-normal" },
			{ GEDIT_TAB_STATE_LOADING,
			  "GEDIT_TAB_STATE_LOADING",
			  "state-loading" },
			{ GEDIT_TAB_STATE_REVERTING,
			  "GEDIT_TAB_STATE_REVERTING",
			  "state-reverting" },
			{ GEDIT_TAB_STATE_SAVING,
			  "GEDIT_TAB_STATE_SAVING",
			  "state-saving" },
			{ GEDIT_TAB_STATE_PRINTING,
			  "GEDIT_TAB_STATE_PRINTING",
			  "state-printing" },
			{ GEDIT_TAB_STATE_PRINT_PREVIEWING,
			  "GEDIT_TAB_STATE_PRINT_PREVIEWING",
			  "state-print-previewing" },
			{ GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW,
			  "GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW",
			  "state-showing-print-preview" },
			{ GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE,
			  "GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE",
			  "state-generic-not-editable" },
			{ GEDIT_TAB_STATE_LOADING_ERROR,
			  "GEDIT_TAB_STATE_LOADING_ERROR",
			  "state-loading-error" },
			{ GEDIT_TAB_STATE_REVERTING_ERROR,
			  "GEDIT_TAB_STATE_REVERTING_ERROR",
			  "state-reverting-error" },
			{ GEDIT_TAB_STATE_SAVING_ERROR,
			  "GEDIT_TAB_STATE_SAVING_ERROR",
			  "state-saving-error" },
			{ GEDIT_TAB_STATE_GENERIC_ERROR,
			  "GEDIT_TAB_STATE_GENERIC_ERROR",
			  "state-generic-error" },
			{ GEDIT_TAB_STATE_CLOSING,
			  "GEDIT_TAB_STATE_CLOSING",
			  "state-closing" },
			{ GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION,
			  "GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION",
			  "state-externally-modified-notification" },
			{ GEDIT_TAB_NUM_OF_STATES,
			  "GEDIT_TAB_NUM_OF_STATES",
			  "num-of-states" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GeditTabState"),
				values);
	}
	return the_type;
}

/* enumerations from "gedit/gedit-window.h" */
#include "gedit/gedit-window.h"

GType
gedit_window_state_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GEDIT_WINDOW_STATE_NORMAL,
			  "GEDIT_WINDOW_STATE_NORMAL",
			  "normal" },
			{ GEDIT_WINDOW_STATE_SAVING,
			  "GEDIT_WINDOW_STATE_SAVING",
			  "saving" },
			{ GEDIT_WINDOW_STATE_PRINTING,
			  "GEDIT_WINDOW_STATE_PRINTING",
			  "printing" },
			{ GEDIT_WINDOW_STATE_LOADING,
			  "GEDIT_WINDOW_STATE_LOADING",
			  "loading" },
			{ GEDIT_WINDOW_STATE_ERROR,
			  "GEDIT_WINDOW_STATE_ERROR",
			  "error" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GeditWindowState"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

